var platoon = require('platoon');


exports.TestRequire = platoon.unit({},
  function(assert) {
    "Test to make sure we can require correctly.";
    // Make sure we can require correctly.
    assert.doesNotThrow(function() {
      var Config = require('../config').Config;
    });
  }
);

var Config = require('../config').Config;

exports.TestInstantiation = platoon.unit({},
  function(assert) {
    "Test to make sure we can instantiate correctly.";
    var non_existent = new Config('./foobar.txt');
    var busted = new Config('./sample_files/broken_config.json');
    var golden = new Config('./sample_files/golden_config.json');
    
    assert.equal(non_existent.filename, './foobar.txt');
    assert.equal(busted.filename, './sample_files/broken_config.json');
    assert.equal(golden.filename, './sample_files/golden_config.json');
  }
);

exports.TestLoading = platoon.unit({},
  function(assert) {
    "Test to make sure loads never throw errors.";
    // Test with a non-existent file.
    assert.doesNotThrow(function() {
      var non_existent = new Config('foobar.txt');
      var data = non_existent.load();
    });

    assert.doesNotThrow(function() {
      var busted = new Config('sample_files/broken_config.json');
      var data = busted.load();
    });

    assert.doesNotThrow(function() {
      var golden = new Config('sample_files/golden_config.json');
      var data = golden.load();
    });
  },
  function(assert) {
    "Ensure that loading data looks correct.";
    var non_existent = new Config('foobar.txt');
    var busted = new Config('sample_files/broken_config.json');
    var golden = new Config('sample_files/golden_config.json');

    non_existent.load(assert.async(function(err, data) {
        assert.strictEqual(data, null);
        assert.isInstance(err, Error);
    }));
    busted.load(assert.async(function(err, data) {
        assert.strictEqual(data, null);
        assert.isInstance(err, Error);
    })); 
    golden.load(assert.async(function(err, data) {
        assert.strictEqual(err, null);
        assert.deepEqual({
          port: 8080,
          version: [1, 0, 0],
          twitter_auth: {
            'username': 'bobbytables',
            'password': "Robert'); DROP TABLE Students;--"
          }
        });
    }));
  }
);
